@@ -27,6 +27,7 @@ class AbstractRunner(ABC):
         self.save_model = save_model
         self.running_date = running_date
         self.starting_date = starting_date
+        self.maximize_perf = True
         self.minimize_drawdown = True
         self.equaly_weighted = True
         self.erc_weighted = True
@@ -76,6 +77,25 @@ class SimpleEnsemblingRunner(AbstractRunner):
 
         print('max after filtering ' + str(max(df.index)))
 
+        check_maxperf_existence = saver.checkRunExistence('mp_' + savingKey)
+        if self.maximize_perf and not check_maxperf_existence:
+            print('maximizing perf')
+            df_res = df.copy()
+            portfolio, weight_mat = allocation.rolling_allocation(
+                allocation.maxPerf,
+                df_res,
+                n=n,
+                s=s,
+                normalize=True,
+                low_bound=low_bound,
+                up_bound=up_bound,
+                filtering_threshold=0.9
+            )
+            df_ret = df_res.fillna(method='bfill').pct_change().fillna(0).copy()
+            weight_normalized, last_predicted_weights = weights.weights_shift(weight_mat=weight_mat)
+            portfolio = np.cumprod(np.prod(df_ret * weight_normalized.values + 1, axis=1))
+            saver.saveResults('mp_'+savingKey, portfolio, weight_normalized,last_predicted_weights)
+
         check_drawdown_existence = saver.checkRunExistence('dd_'+savingKey)
         if self.minimize_drawdown and not check_drawdown_existence:
             print('minimizing drawdown')
