@@ -150,8 +150,9 @@ class ParallelRunResultAnalyzer():
                 if results_df is None:
                     results_df = local_df.copy()
                 else:
-                    print('merging table ' + str(local_df.shape))
-                    results_df = pd.merge(results_df, local_df, how='left', on=['Date'])
+                    if local_df.shape[0]>0:
+                        print('merging table ' + str(local_df.shape))
+                        results_df = pd.merge(results_df, local_df, how='left', on=['Date'])
             else :
                 break
         return results_df
