@@ -407,6 +407,32 @@ def minSharpe(X, w0=None, normalize=False, low_bound=0., up_bound=1.0):
     return result.x.reshape([N, 1])
 
 
+def maxPerf(X,  w0=None, normalize=False, low_bound=0., up_bound=1.0):
+    T, N = X.shape
+    up_bound = max(up_bound, 1 / N)
+
+    def f_performance(w, X):
+        cumulated_perf = np.cumprod(X @ w + 1)
+        final_cumulated_perf = cumulated_perf[-1]
+        return final_cumulated_perf
+
+    toOptimize = lambda w : f_performance(w,X)
+
+    # Set inital weights
+    if w0 is None:
+        w0 = np.ones([N]) / N
+
+    const_sum = LinearConstraint(np.ones([1, N]), [1], [1])
+    const_ind = Bounds(low_bound * np.ones([N]), up_bound * np.ones([N]))
+    result = minimize(
+        toOptimize,
+        w0,
+        method='SLSQP',
+        constraints=[const_sum],
+        bounds=const_ind
+    )
+
+    return result.x.reshape([N, 1])
 
 def minDrawdown(X,  w0=None, normalize=False, low_bound=0., up_bound=1.0):
     T, N = X.shape
