@@ -90,23 +90,25 @@ def generate_lo_slope_ma(lookback_windows, pente_windows, contravariants,):
 #                                     })
 #     return parameters
 
-def generate_fourier_wvt_decomposition(lookback_windows,contravariants,n_harms,fft_filter_types,dec_levels,thresholds):
+def generate_fourier_wvt_decomposition(lookback_windows,contravariants,n_harms,fft_filter_types,wavelet_filters,dec_levels,thresholds):
     parameters = []
     for lookback_window in lookback_windows:
         for contravariant in contravariants:
             for fft_filter_type in fft_filter_types:
                 for n_harm in n_harms:
                     for dec_level in dec_levels:
-                        for threshold in thresholds:
-                                if n_harm < lookback_window:
-                                    parameters.append({
-                                        'lookback_window':lookback_window,
-                                        'contravariant':contravariant,
-                                        'fft_filter_type':fft_filter_type,
-                                        'n_harm':n_harm,
-                                        'dec_level':dec_level,
-                                        'threshold':threshold,
-                                    })
+                        for filter_name in wavelet_filters:
+                            for threshold in thresholds:
+                                    if n_harm < lookback_window:
+                                        parameters.append({
+                                            'lookback_window':lookback_window,
+                                            'contravariant':contravariant,
+                                            'fft_filter_type':fft_filter_type,
+                                            'n_harm':n_harm,
+                                            'filter_name':filter_name,
+                                            'dec_level':dec_level,
+                                            'threshold':threshold,
+                                        })
     return parameters
 
 def generate_kalman(lookback_windows,contravariants,n_harms,fft_filter_types,thresholds,obs_covs):
