@@ -8,6 +8,8 @@ from napoleontoolbox.tools.analyze_tools import roll_corr
 from scipy import stats
 from numpy import fft
 from pykalman import KalmanFilter
+import pywt
+import random
 from scipy.ndimage.interpolation import shift
 from napoleontoolbox.wavelets_fft import wavelet_features
 
@@ -1130,6 +1132,20 @@ def optimize_filtering_wlt(decomp_components, threshold):
     return output_approx
 
 
+def is_discrete(wavelet_to_check, discrete):
+    prefix_size = len(wavelet_to_check)
+    all_prefixes = [wavelet[:prefix_size] for wavelet in discrete]
+    return wavelet_to_check in all_prefixes
+
+def set_wavelet_filters(kind='discrete'):
+    wavelet_families = pywt.families()
+    discrete_wavelets = pywt.wavelist(family=None, kind=kind)
+    selected_filters = []
+    for wavelet in wavelet_families:
+        if is_discrete(wavelet, discrete_wavelets):
+            selected_filters.append(random.choice(pywt.wavelist(family=wavelet, kind=kind)))
+    return selected_filters
+
 def fourier_wvt_decompo_lo(data=None, filter_name='haar', contravariant=1., dec_level=2, n_harm=5, fft_filter_type='low', threshold=0.7, **kwargs):
     n_predict = 1
     try:
